{% extends "account/base.html" %}

{% block head_title %}Sign out{% endblock %}

{% block content %}
<div class="flex flex-col items-center justify-center w-screen h-screen text-gray-700 bg-gray-200">
  <form method="post" action="{% url 'account_logout' %}" class="flex flex-col p-12 bg-white rounded shadow-lg">
    {% csrf_token %}
    {% if redirect_field_value %}
    <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}"/>
    {% endif %}

    <p>Are you sure you want to sign out?</p>
    <button type="submit" class="w-64 h-12 px-6 mt-8 text-lg text-white uppercase bg-blue-600 rounded text-bold hover:bg-blue-700">Sign Out</button>
  </form>
</div>
{% endblock %}
