{% extends "account/base.html" %}

{% block head_title %}Sign up{% endblock %}

{% block content %}
<div class="flex flex-col items-center justify-center w-screen h-screen text-gray-700 bg-gray-200">
  <form class="flex flex-col p-12 bg-white rounded shadow-lg" id="signup_form" method="post" action="{% url 'account_signup' %}" novalidate>
    {% csrf_token %}

    <h1 class="mb-5 text-3xl text-center">Sign up</h1>
    {% include "account/_render_form.html" %}

		<button type="submit" class="w-64 h-12 px-6 mt-8 text-lg text-white uppercase bg-blue-600 rounded text-bold hover:bg-blue-700">Sign Up</button>

    {% if redirect_field_value %}
    <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
    {% endif %}
  </form>

  <div class="flex justify-center mt-6">
    <a class="text-blue-400 hover:text-blue-500" href="{{ login_url }}">Already have an account? Sign in.</a>
  </div>
</div>
{% endblock %}
